==> nested_json_to_csv-1.0.2.tgz: package/index.js <==
// const path = require("path");
// const os = require("os");
// const fs = require("fs");


// write it to a file
// fs.writeFileSync("./csvFilePath.csv", "csvFile");
printError = function (message) {
    console.error(`\n===========================================\n${message}\n===========================================\n`)
}


var addHeaders = function (headers, csv) {
    headers.forEach((header) => {
        csv += header + ","
    });
    csv += '\n';

    return csv;
}

var fetchAll = function (json, headers) {
    csv = "";
    headers.forEach((header) => {
        csv += fetch(header, json);
    });
    csv += '\n';
    return csv;
}

var fetch = function (path, json) {
    if (path.includes('.')) {
        return fetch(path.substring(path.indexOf('.') + 1), json[path.substring(0, path.indexOf('.'))]);
    } else {
        if (typeof json[path] != 'string') {
            printError("ERROR your json file is too nested please set the third parameter to true when you call (jsonToCsv)\nOr if the third parameter is already set to true then please be carefull in the second paramter which is the headers each one should an accurate path in the json")
            throw new Error;
        }
        // just in case
        if (json[path].includes(','))
            json[path].replace(',', '.');

        return json[path] + ",";

    }
}



exports.nestedJsonToCsv = (jsonData, headers, mutiples) => {

    if (headers == undefined || headers == []) {
        printError("Please pass an array of strings as a second parameter(headers)");
        //TODO: add a documentation link for this
        throw new Error;
    }



    var csv = "";
    var json = new Map();
    json = new Map(Object.entries(jsonData));

    csv = addHeaders(headers, csv);
    if (!!mutiples) {
        json.forEach((value, key, map) => {
            csv += fetchAll(value, headers);
        });
    } else csv += fetchAll(json, headers);

    return csv;
};


// var csv = nestedJsonToCsv({ "1": { "test": { "test": "test1" } }, "2": { "test": { "test": "test1" } }, "3": { "test": { "test": "test1" } } }, ["test.test"], true);

// console.log(csv);

==> nested_json_to_csv-1.0.3.tgz: package/index.js <==
// const path = require("path");
// const os = require("os");
// const fs = require("fs");


// write it to a file
// fs.writeFileSync("./csvFilePath.csv", "csvFile");
printError = function (message) {
    console.error(`\n===========================================\n${message}\n===========================================\n`)
}


var addHeaders = function (headers, csv) {
    headers.forEach((header) => {
        csv += header + ","
    });
    csv += '\n';

    return csv;
}

var fetchAll = function (json, headers) {
    csv = "";
    headers.forEach((header) => {
        csv += fetch(header, json);
    });
    csv += '\n';
    return csv;
}

var fetch = function (path, json) {
    if (path.includes('.')) {
        return fetch(path.substring(path.indexOf('.') + 1), json[path.substring(0, path.indexOf('.'))]);
    } else {
        if (typeof json[path] != 'string') {
            printError("ERROR your json file is too nested please set the third parameter to true when you call (jsonToCsv)\nOr if the third parameter is already set to true then please be carefull in the second paramter which is the headers each one should an accurate path in the json")
            throw new Error;
        }
        if (json[path].includes(','))
            json[path].replace(',', '.');

        return json[path] + ",";

    }
}



exports.nestedJsonToCsv = (json, headers, mutiples) => {

    if (headers == undefined || headers == []) {
        printError("Please pass an array of strings as a second parameter(headers)");
        //TODO: add a documentation link for this
        throw new Error;
    }

    var csv = "";

    csv = addHeaders(headers, csv);
    if (!!mutiples) {
        json.forEach((value, key, map) => {
            csv += fetchAll(value, headers);
        });
    } else csv += fetchAll(json, headers);

    return csv;
};


// var csv = nestedJsonToCsv({ "1": { "test": { "test": "test1" } }, "2": { "test": { "test": "test1" } }, "3": { "test": { "test": "test1" } } }, ["test.test"], true);

// console.log(csv);
